%bcond_with bootstrap

Name:           mockito
Version:        5.8.0
Release:        %mkrel 2
Group:          Development/Java
Summary:        Tasty mocking framework for unit tests in Java
License:        MIT
URL:            https://site.mockito.org/
BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch

# ./generate-tarball.sh
Source0:        %{name}-%{version}.tar.gz
Source1:        generate-tarball.sh

# A custom build script to allow building with maven instead of gradle
Source2:        aggregator.pom

# Maven central POMs for subprojects
Source3:        https://repo1.maven.org/maven2/org/mockito/mockito-core/%{version}/mockito-core-%{version}.pom
Source4:        https://repo1.maven.org/maven2/org/mockito/mockito-junit-jupiter/%{version}/mockito-junit-jupiter-%{version}.pom

# Mockito expects byte-buddy to have a shaded/bundled version of ASM, but
# we don't bundle in Fedora, so this patch makes mockito use ASM explicitly
Patch0:         use-unbundled-asm.patch

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(net.bytebuddy:byte-buddy)
BuildRequires:  mvn(net.bytebuddy:byte-buddy-agent)
BuildRequires:  mvn(net.bytebuddy:byte-buddy-dep)
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter-api)
BuildRequires:  mvn(org.objenesis:objenesis)
BuildRequires:  mvn(org.opentest4j:opentest4j)
%endif
Obsoletes: %{name}-inline < 4

%description
Mockito is a mocking framework that tastes really good. It lets you write
beautiful tests with clean & simple API. Mockito doesn't give you hangover
because the tests are very readable and they produce clean verification
errors.

%package javadoc
Summary: Javadocs for %{name}

%description javadoc
This package contains the API documentation for %{name}.

%package junit-jupiter
Summary:        Mockito JUnit 5 support
Requires:       %{name} = %{version}-%{release}

%description junit-jupiter
Mockito JUnit 5 support.

%prep
%autosetup -p1

cp %{SOURCE2} aggregator.pom
cp %{SOURCE3} pom.xml
cp %{SOURCE4} subprojects/junit-jupiter/pom.xml

# Disable failing test
# TODO check status: https://github.com/mockito/mockito/issues/2162
sed -i '/add_listeners_concurrently_sanity_check/i @org.junit.Ignore' src/test/java/org/mockitousage/debugging/StubbingLookupListenerCallbackTest.java

# Workaround easymock incompatibility with Java 17 that should be fixed
# in easymock 4.4: https://github.com/easymock/easymock/issues/274
%pom_add_plugin :maven-surefire-plugin . "<configuration>
    <argLine>--add-opens=java.base/sun.reflect.generics.reflectiveObjects=ALL-UNNAMED</argLine></configuration>"

# Compatibility alias
%mvn_alias org.%{name}:%{name}-core org.%{name}:%{name}-all

%pom_add_dep junit:junit
%pom_add_dep net.bytebuddy:byte-buddy-dep
%pom_remove_dep org.objenesis:objenesis
%pom_add_dep org.objenesis:objenesis
%pom_add_dep org.opentest4j:opentest4j

%pom_remove_dep org.junit.jupiter:junit-jupiter-api subprojects/junit-jupiter
%pom_add_dep org.junit.jupiter:junit-jupiter-api subprojects/junit-jupiter

mkdir -p src/main/resources/mockito-extensions
echo 'member-accessor-module' > src/main/resources/mockito-extensions/org.mockito.plugins.MemberAccessor
echo 'mock-maker-subclass' > src/main/resources/mockito-extensions/org.mockito.plugins.MockMaker

# see gradle/mockito-core/inline-mock.gradle
%pom_xpath_inject 'pom:project/pom:build/pom:plugins' '
<plugin>
  <groupId>org.apache.maven.plugins</groupId>
  <artifactId>maven-antrun-plugin</artifactId>
  <version>any</version>
  <executions>
    <execution>
      <phase>process-classes</phase>
      <configuration>
        <target>
          <copy file="${project.build.outputDirectory}/org/mockito/internal/creation/bytebuddy/inject/MockMethodDispatcher.class"
            tofile="${project.build.outputDirectory}/org/mockito/internal/creation/bytebuddy/inject/MockMethodDispatcher.raw"/>
        </target>
      </configuration>
      <goals>
        <goal>run</goal>
      </goals>
    </execution>
  </executions>
</plugin>
<plugin>
  <groupId>org.apache.maven.plugins</groupId>
  <artifactId>maven-jar-plugin</artifactId>
  <version>any</version>
  <configuration>
    <excludes>
      <exclude>org/mockito/internal/creation/bytebuddy/inject/*.class</exclude>
    </excludes>
  </configuration>
</plugin>
'

%mvn_package :aggregator __noinstall

%build
%mvn_build -f -- -Dmaven.compiler.release=11 -Dproject.build.sourceEncoding=UTF-8 -f aggregator.pom

%mvn_package org.mockito:mockito-junit-jupiter junit-jupiter

%install
%mvn_install

%files -f .mfiles
%license LICENSE
%doc README.md doc/design-docs/custom-argument-matching.md

%files junit-jupiter -f .mfiles-junit-jupiter

%files javadoc -f .mfiles-javadoc
%license LICENSE




%changelog
* Sun Jun 29 2025 umeabot <umeabot> 5.8.0-2.mga10
+ Revision: 2223093
- Mageia 10 Mass Rebuild

* Tue May 21 2024 ns80 <ns80> 5.8.0-1.mga10
+ Revision: 2065610
- new version 5.8.0 for java 21

* Mon Jul 25 2022 neoclust <neoclust> 3.12.4-2.mga9
+ Revision: 1871091
- Disable bootstrap

* Sun Jul 24 2022 neoclust <neoclust> 3.12.4-1.mga9
+ Revision: 1870792
- New version 3.12.4
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Mon Jan 04 2021 neoclust <neoclust> 3.5.13-1.mga8
+ Revision: 1668531
- New version 3.5.13

* Fri Sep 04 2020 daviddavid <daviddavid> 2.28.2-1.mga8
+ Revision: 1621896
- Update to version 2.28.2
- Rebuilt for JDK-11

* Sat Feb 15 2020 umeabot <umeabot> 2.23.9-2.mga8
+ Revision: 1527521
- Mageia 8 Mass Rebuild

* Wed Jul 17 2019 daviddavid <daviddavid> 2.23.9-1.mga8
+ Revision: 1422269
- Update to latest upstream version 2.23.9
- Switch to maven build system using a custom pom to avoid a dep on gradle
- Re-add compatibility alias for 'mockito-all'
- Set the source encoding for the build

* Wed Dec 12 2018 daviddavid <daviddavid> 1.10.19-12.mga7
+ Revision: 1340808
- Remove bundled minified js from javadoc

* Wed Sep 19 2018 umeabot <umeabot> 1.10.19-11.mga7
+ Revision: 1264456
- Mageia 7 Mass Rebuild

* Fri Apr 29 2016 daviddavid <daviddavid> 1.10.19-10.mga6
+ Revision: 1007715
- Explicitly import more cglib packages in OSGi metadata to prevent mockito
  failing under certain circumstances during Eclipse test suites
- Require hamcrest explicitly in OSGi metadata
+ neoclust <neoclust>
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 1.10.19-8.mga6
+ Revision: 977340
- First rebuild of the java stack
- sync package mockito with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.9.0-8.mga5
+ Revision: 746821
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.9.0-7.mga5
+ Revision: 682555
- Mageia 5 Mass Rebuild

* Wed Sep 03 2014 dmorgan <dmorgan> 1.9.0-6.mga5
+ Revision: 671666
- Fix Require into junit instead of junit4

* Mon Oct 21 2013 umeabot <umeabot> 1.9.0-5.mga4
+ Revision: 537732
- Mageia 4 Mass Rebuild

* Fri Sep 27 2013 dmorgan <dmorgan> 1.9.0-4.mga4
+ Revision: 487574
- Patched LocalizedMatcher due to hamcrest update, (bug upstream)

* Sat Jan 12 2013 umeabot <umeabot> 1.9.0-3.mga3
+ Revision: 360178
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Sep 13 2012 dmorgan <dmorgan> 1.9.0-2.mga3
+ Revision: 293363
- Fix sources
- Make mockito an OSGi bundle using upstream bnd config.

* Mon Jul 09 2012 dmorgan <dmorgan> 1.9.0-1.mga3
+ Revision: 269023
- New version 1.9.0

* Thu Aug 11 2011 dmorgan <dmorgan> 1.8.5-1.mga2
+ Revision: 132701
- Clean spec file
+ gil <gil>
- edit spec file
- imported package mockito


* Thu Jun 30 2011 gil <gil> 1.8.5-0.%%mkrel
- initial rpm